# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(summarytools)
library(tidyverse)
library(kableExtra)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

################################
# BRIEF SUMMARY OF ALL VARIABLES
################################

# str provides the information that you can also see by clicking the arrow 
# next to the dataframe name in the Global Environment.
str(MYDATA)

# summary gives a concise overall summary of all variables, with some limitations.
# This is useful as a first step.
summary(MYDATA)

# dfsummary gives the mean, standard deviation, median and IQR for numeric variables
dfSummary(MYDATA)

##################
# FREQUENCY TABLES
##################

# table provides the frequencies for a categorical variable
table(MYDATA$CATEGORICAL_VARIABLE)

# freq provides frequencies and percentages for a categorical variable
freq(MYDATA, CATEGORICAL_VARIABLE)


#############
# CROSSTABLES 
#############

# xtabs provides a crosstabulation with frequencies

xtabs(~ MYDATA$CATEGORICAL_VARIABLE1 + MYDATA$CATEGORICAL_VARIABLE2)

# ctable gives a crosstabulation with frequencies and percentages
ctable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2)


################################################
# DESCRIPTIVE STATISTICS FOR NUMERICAL VARIABLES
################################################

# Mean, SD and n
descr(MYDATA, NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd"))

# Five number summary, including median and quartiles
descr(MYDATA, NUMERICAL_VARIABLE, stats = c("n.valid", "min", "q1", "med", "q3", "max"))

# Pearson Correlation between numeric variables
# Two numeric variables in a data frame
cor(MYDATA$NUMERICAL_VARIABLE1,MYDATA$NUMERICAL_VARIABLE2,method = "pearson")
# Data frame with all numerical variables
cor(MYDATA, method = "pearson")

######################################################################################
# DESCRIPTIVE STATISTICS FOR NUMERICAL VARIABLES - IMPROVED TABLES IF USING R MARKDOWN
######################################################################################
# Additional code for neater tables, some examples
# Adjust the number of digits (decimal places) if necessary

# Mean, SD and n
table1 <- descr(MYDATA, NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd"))
knitr::kable(table1, digits = 1) %>%  
  kable_styling(position = "center", full_width = FALSE)

# Five number summary, including median and quartiles
table2 <- descr(MYDATA, NUMERICAL_VARIABLE, stats = c("n.valid", "min", "q1", "med", "q3", "max"))
knitr::kable(table2, digits = 1) %>%  
  kable_styling(position = "center", full_width = FALSE)

# Pearson Correlation between numeric variables
# Data frame with all numerical variables
corrtable <- cor(MYDATA, method = "pearson")
knitr::kable(corrtable, digits = 2) %>%  
  kable_styling(position = "center", full_width = FALSE)

#########################################################
# DESCRIPTIVE STATISTICS FOR NUMERICAL VARIABLES BY GROUP
#########################################################

# Mean, SD and n
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  descr(NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd"))

# Five number summary, including median and quartiles
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  descr(NUMERICAL_VARIABLE, stats = c("n.valid", "min", "q1", "med", "q3", "max"))

# Pearson Correlation between numeric variables
# Two numeric variables in a data frame
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  summarise(cor = cor(NUMERICAL_VARIABLE1, NUMERICAL_VARIABLE2, method = "pearson"))
# Data frame with all numerical variables
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  summarise(correlation = cor(MYDATA, method = "pearson"))

###############################################################################################
# DESCRIPTIVE STATISTICS FOR NUMERICAL VARIABLES BY GROUP - IMPROVED TABLES IF USING R MARKDOWN
###############################################################################################
# Additional code for neater tables, some examples
# Adjust the number of digits (decimal places) if necessary

# Mean, SD and n
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  descr(NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd")) %>%
  tb() %>%
  knitr::kable(digits = 1) %>%  
  kable_styling(position = "center", full_width = FALSE)

# Five number summary, including median and quartiles
MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  descr(NUMERICAL_VARIABLE, stats = c("n.valid", "min", "q1", "med", "q3", "max")) %>%
  tb() %>%
  knitr::kable(digits = 1) %>%  
  kable_styling(position = "center", full_width = FALSE)
