# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(dplyr)
library(janitor)

# Read in the data.
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# You can look at the data by clicking on the file name in the 
# Global Environment pane on the right.

# For categorical variables it is important to see how R has read them in.  
# In the Global Environment, click the arrow next to the file name to see how variable have been read in.
# If the categorical variable has been read in as a "Factor", you are good to go.
# If the categorical variable has been read in as a character "Chr", 
# you will need to run some code to define the variable as a factor.
# Graphs for categorical variables use factors.

# Here is the code if you need to change a variable to a factor.
# In the code, you will need to edit MYDATA and CATEGORICAL_VARIABLE.

MYDATA$CATEGORICAL_VARIABLE <- factor(MYDATA$CATEGORICAL_VARIABLE)


# Define some general properties of the graphs you wish to produce.
# This is a 'theme' for your graphs.
# Here the theme is named 'Theme'; it defines font sizes.
# You may wish to ajust this for your screen.


Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16))


#################################################
# VISUALISING ONE CATEGORICAL VARIABLE: BAR CHART
#################################################

# Create a bar chart with frequncies.
# "..count .." plots the frequency on the y axis.
# coord_flip transposes the graph.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE and NICE AXIS LABEL!

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE, y = ..count..)) + 
  geom_bar(width = 0.5) +
  labs(x="NICE AXIS LABEL", y = "Frequency") +
  coord_flip() +
  Theme

# Create a percentage bar chart.
# "100*(..count..)/sum(..count..)" plots the percentage on the y axis.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE and NICE AXIS LABEL!

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE, y = 100*(..count..)/sum(..count..))) + 
  geom_bar(width = 0.5) +
  labs(x="NICE AXIS LABEL", y = "Percent") +
  Theme +
  coord_flip()

#################################################
# VISUALISING ONE CATEGORICAL VARIABLE: DOT CHART
#################################################

# Create a dot chart.
# First need to find the frequency in each level of the categorical variable.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE and NICE AXIS LABEL!


freqTable <- tabyl(MYDATA, CATEGORICAL_VARIABLE)

# Check the contents of the table.
# Note that the proportion is incorrectly labelled as the percent.

freqTable

# Note we are now using the data summarised in freqTable.
# This code will plot the frequency.
# In the code, you will need to edit CATEGORICAL_VARIABLE and NICE AXIS LABEL!

ggplot(freqTable, aes(x = n, y = CATEGORICAL_VARIABLE)) + 
  geom_point() +
  labs(x = "Frequency", y = "NICE AXIS LABEL") +
  Theme

# Create a percentage dot chart.
# To calculate the percentage, we need to multiply the proportion (incorrectly labelled percent) by 100
# How confusing is that!
# In the code, you will need to edit CATEGORICAL_VARIABLE (several times) and NICE AXIS LABEL!

ggplot(freqTable, aes(x = 100*percent, y = CATEGORICAL_VARIABLE)) + 
  geom_point(size = 3) +
    geom_segment(aes(x=0, 
                   xend=100*percent, 
                   y=CATEGORICAL_VARIABLE, 
                   yend=CATEGORICAL_VARIABLE)) +
  labs(x = "Percentage", y = "NICE AXIS LABEL") +
  Theme

