# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)

# Define some general properties of the graphs you wish to produce.
# This is a 'theme' for your graphs.
# Here the theme is named 'Theme'; it defines font sizes.
# You may wish to ajust this for your screen.

Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16))

# Read in the data. 
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# You can look at the data by clicking on the file name in the 
# Global Environment pane on the right.


###############################################
# VISUALISING ONE NUMERICAL VARIABLE: HISTOGRAM
###############################################

# Create a histogram.
# Remember ... objects have names.  Here a histogram is given the name h1.
# In the code, you will need to edit MYDATA, NUMERICAL_VARIABLE and NICE AXIS LABEL!
# You can edit the number of bins, using 'bins ="; between 5 and 15 can be useful.

h1 <- ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE)) +
      geom_histogram(bins = 15) +
      labs(x="NICE AXIS LABEL!") +
      Theme
h1 

# Save the  histogram.
# This will save the graph in a pdf file; other formats can be used.

ggsave("My histogram.pdf", plot = h1)


###############################################
# VISUALISING ONE NUMERICAL VARIABLE: DOTPLOTS
###############################################

# Create a dotplot.
# In the code, you will need to edit MYDATA, NUMERICAL_VARIABLE and NICE AXIS LABEL! and NICE TITLE PLEASE!
# You can add `binwidth = ` inside geom_dotplot and specify the interval width for you dotplot.

d1 <- ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE)) + 
      geom_dotplot(dotsize = 0.4) +
      labs(x="NICE AXIS LABEL!", title="NICE TITLE PLEASE!") +
      scale_y_continuous(breaks=NULL) +
      Theme
d1

# If you wanted to save the plot in a separate file:

ggsave("My dotplot.pdf", plot = d1)

###########################################################
# VISUALISING ONE NUMERICAL VARIABLE: INDIVIDUAL VALUE PLOT
###########################################################

# Create an individual value plot.
# In the code, you will need to edit MYDATA, NUMERICAL_VARIABLE and NICE AXIS LABEL! and NICE TITLE PLEASE!
# This is the same as a dot plot, with the points centred.

iv1 <- ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE)) + 
  geom_dotplot(stackdir = "center", dotsize = 0.4) +
  labs(x="NICE AXIS LABEL!", y = "", title="NICE TITLE PLEASE!") +
  scale_y_continuous(breaks=NULL) +
  Theme
iv1


###############################################
# VISUALISING ONE NUMERICAL VARIABLE: BOX PLOTS
###############################################

# Create a boxplot.
# Note that this creates a "y-axis" which is not relevant; 
# we remove this in refining the graph below.

# create a boxplot.

b1 <- ggplot(MYDATA, aes(y=NUMERICAL_VARIABLE)) + 
      geom_boxplot() + 
      labs(y="NICE AXIS LABEL!") +
      coord_flip() +
      scale_x_continuous(breaks=NULL) +
      Theme
b1

# Save the boxplot and specify the aspect ratio.

ggsave("My boxplot.pdf", plot = b2, width = 20, height = 4 )


# Save many plots into a single pdf file
# First the pdf file is "open"
# Next the plots to include are listed
# Finally dev.off() closes the pdf file

pdf("manyplots.pdf")
h1
d1
b1
dev.off()
