# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(dplyr)
library(forcats)
library(htmltools)
library(ggExtra)

# Define some general properties of the graps you wish to produce.
# This is a 'theme' for your graphs.
# Change the font sizes if necessary.

Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16))

# Read in the data.
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")


#################################################
# VISUALISING TWO CATEGORICAL VARIABLES: BARCHART
#################################################


# Create a bar chart of frequencies with CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.
# "..count .." plots the frequency on the y axis.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE1, CATEGORICAL_VARIABLE2, 
# NICE CATEGORICAL_VARIABLE1 LABEL and NICE TITLE!

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE1, y = ..count.., fill=CATEGORICAL_VARIABLE2)) + 
  geom_bar(position="dodge") +
  labs(x="NICE CATEGORICAL_VARIABLE1 LABEL", y = "Frequency", title = "NICE TITLE") +
  Theme +
  coord_flip()

# Create a bar chart of percentages with CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.
# Note that this is percentages overall.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE1, CATEGORICAL_VARIABLE2, 
# NICE CATEGORICAL_VARIABLE1 LABEL and NICE TITLE!

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE1, y = 100*(..count..)/sum(..count..), fill=CATEGORICAL_VARIABLE2)) + 
  geom_bar(position="dodge") +
  labs(x="NICE CATEGORICAL_VARIABLE1 LABEL", y = "Percent", title = "NICE TITLE (%)") +
  Theme +
  coord_flip()


#################################################
# VISUALISING TWO CATEGORICAL VARIABLES: DOTCHART
#################################################

# Create a dot chart of two categorical variables.
# First find the frequency of the combinations of CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.
# Find the proportion of each level of CATEGORICAL_VARIABLE1 within each level of CATEGORICAL_VARIABLE2.(GENDER)

# ungroup() at the end prevents future surprises 
# if you do further operations on TwoWaytable
# and they are unexpectedly done groupwise.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.

TwoWaytable <- MYDATA %>%
  count(CATEGORICAL_VARIABLE2, CATEGORICAL_VARIABLE1) %>%
  group_by(CATEGORICAL_VARIABLE2) %>%
  mutate(proportion = n / sum(n)) %>%
  ungroup()

# Check the contents of the table.

TwoWaytable

# Plot the summary table using a dot chart to show the frequencies.
# facet_grid specify showing each level of CATEGORICAL_VARIABLE2 in a separate panel in rows.
# In the code, you will need to edit CATEGORICAL_VARIABLE1, CATEGORICAL_VARIABLE2, 
# and CATEGORICAL_VARIABLE1 LABEL.

ggplot(TwoWaytable, aes(x = n, y = CATEGORICAL_VARIABLE1)) + 
  geom_point() + 
  facet_grid(rows=vars(CATEGORICAL_VARIABLE2)) +
  labs(x = "Frequency", y = "CATEGORICAL_VARIABLE1 LABEL") +
  Theme

# Plot the summary table using a dot chart to show the percentages.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.

ggplot(TwoWaytable, aes(x = 100*proportion, y = CATEGORICAL_VARIABLE1)) + 
  geom_point(size = 3) +
  geom_segment(aes(x=0, 
                   xend=100*proportion, 
                   y=CATEGORICAL_VARIABLE1, 
                   yend=CATEGORICAL_VARIABLE1)) +
  facet_grid(rows=vars(CATEGORICAL_VARIABLE2)) +
  labs(x = "Percentage within CATEGORICAL_VARIABLE2", y = "", title = "CATEGORICAL_VARIABLE1 (%) within each level of CATEGORICAL_VARIABLE2") +
  Theme


