# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(dplyr)
library(forcats)
library(htmltools)
library(ggExtra)

# Define some general properties of the graps you wish to produce.
# This is a 'theme' for your graphs.
# Change the font sizes if necessary.

Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16))

# Read in the data.
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

###################################################
# VISUALISING TWO NUMERICAL VARIABLES: SCATTERPLOTS
###################################################

# Create a scatterplot.
# In the code, you will need to edit MYDATA, NUMERICAL_VARIABLE1, NUMERICAL_VARIABLE2, 
# NICE X-AXIS LABEL and NICE Y-AXIS LABEL!

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE2)) +
  geom_point() +
  labs(x="NICE X-AXIS LABEL", y = "NICE Y-AXIS LABEL") +
  Theme

# Create a scatterplot with a smoother.

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE2)) +
  geom_point() +
  geom_smooth(se = FALSE) +
  labs(x="NICE X-AXIS LABEL", y = "NICE Y-AXIS LABEL") +
  Theme

# Create a scatterplot with marginal boxplots.

s1 <- ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE2)) +
  geom_point() +
  geom_smooth(se = FALSE) +
  labs(x="NICE X-AXIS LABEL", y = "NICE Y-AXIS LABEL") +
  Theme
s2 <- ggMarginal(s1, type = "boxplot")
s2


# Create a scatterplot with a linear regression line.

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE2)) +
  geom_point() +
  geom_smooth(method=lm, se=FALSE, fullrange=TRUE) +
  labs(x="NICE X-AXIS LABEL", y = "NICE Y-AXIS LABEL") +
  Theme


# Create a scatterplot with groups.
# Yes, that really is three variables!

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE2, colour=CATEGORICAL_VARIABLE)) +
  geom_point() +
  labs(x="NICE X-AXIS LABEL", y = "NICE Y-AXIS LABEL") +
  Theme




######################################################
# VISUALISING TWO NUMERICAL VARIABLES: PLOTS OVER TIME
######################################################

# Create a plot.
# In the code, you will need to edit MYDATA, NUMERICAL_VARIABLE, TIME_VARIABLE, 
# and NICE Y-AXIS LABEL.

ggplot(MYDATA, aes(x=TIME_VARIABLE, y = NUMERICAL_VARIABLE)) +
  geom_point() +
  geom_line() +
  labs(x="Time", y = "NICE Y-AXIS LABEL") +
  Theme

