# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(dplyr)
library(forcats)
library(htmltools)
library(ggExtra)

# Define some general properties of the graps you wish to produce.
# This is a 'theme' for your graphs.
# Change the font sizes if necessary.

Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16))

# Read in the data.
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")


#################################################################
# VISUALISING ONE NUMERICAL VARIABLE AND ONE CATEGORICAL VARIABLE
#################################################################

# For categorical variables it is important to see how R has read them in.  
# In the Global Environment, click the arrow next to the file name to see how variable have been read in.
# If the categorical variable has been read in as a "Factor", you are good to go.
# If the categorical variable has been read in as a character "Chr", 
# you will need to run some code to define the variable as a factor.
# Graphs involving categorical variables use factors.

# Here is the code if you need to change a variable to a factor.
# In the code, you will need to edit MYDATA and CATEGORICAL_VARIABLE.

MYDATA$CATEGORICAL_VARIABLE <- factor(MYDATA$CATEGORICAL_VARIABLE)

####################################################################################
# VISUALISING ONE NUMERICAL VARIABLE AND ONE CATEGORICAL VARIABLE: DOTPLOTS BY GROUP
####################################################################################

# Create dotplots by groups.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE, NUMERICAL_VARIABLE, 
# NICE X-AXIS LABEL and NICE Y-AXIS LABEL!

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
        geom_dotplot(binaxis = 'y', dotsize = 0.5) +
        labs(y ="NICE Y-AXIS LABEL", x = "NICE X-AXIS LABEL") +
        coord_flip() +  
        Theme

##################################################################################################
# VISUALISING ONE NUMERICAL VARIABLE AND ONE CATEGORICAL VARIABLE: INDIVIDUAL VALUE PLOTS BY GROUP
##################################################################################################

# Create individual value plots by groups.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE, NUMERICAL_VARIABLE, 
# NICE X-AXIS LABEL and NICE Y-AXIS LABEL!

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
  geom_dotplot(binaxis = 'y', stackdir='center', dotsize = 0.5) +
  labs(y ="NICE Y-AXIS LABEL", x = "NICE X-AXIS LABEL") +
  coord_flip() +  
  Theme

####################################################################################
# VISUALISING ONE NUMERICAL VARIABLE AND ONE CATEGORICAL VARIABLE: BOXPLOTS BY GROUP
####################################################################################

# Create boxplots by groups.
# In the code, you will need to edit MYDATA, CATEGORICAL_VARIABLE, NUMERICAL_VARIABLE, 
# NICE X-AXIS LABEL and NICE Y-AXIS LABEL!

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
        geom_boxplot() +
        labs(y ="NICE Y-AXIS LABEL", x = "NICE X-AXIS LABEL") +
        coord_flip() +  
        Theme

