# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(GGally)

# Define some general properties of the graps you wish to produce.
# This is a 'theme' for your graphs.
# Change the font sizes if necessary.

Theme <- theme(axis.title.x = element_text(size=16), 
               axis.text.x  = element_text(size=16), 
               axis.title.y = element_text(size=16), 
               axis.text.y  = element_text(size=16), 
               plot.title = element_text(size = 22),
               strip.text = element_text(size = 16)) 

# Read in the data.
# In this script, the file is called MYDATA.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")


###########################################################
# VISUALISING TWO NUMERICAL VARIABLES BROKEN DOWN BY PANELS
###########################################################

# Create a scatterplot with panels (in columns) defined by a CATEGORICAL_VARIABLE.

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE1)) +
       geom_point() +
       facet_grid(cols=vars(CATEGORICAL_VARIABLE)) +
       labs(x="NICE X AXIS LABEL", y = "NICE Y AXIS LABEL") +
       Theme


# Create a scatterplot with panels (in rows) defined by a CATEGORICAL_VARIABLE.

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE1)) +
  geom_point() +
  facet_grid(rows=vars(CATEGORICAL_VARIABLE)) +
  labs(x="NICE X AXIS LABEL", y = "NICE Y AXIS LABEL", title = "NICE TITLE") +
  Theme


# Create a scatterplot with panels defined by CATEGORICAL_VARIABLE1 and CATEGORICAL_VARIABLE2.

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE1, y = NUMERICAL_VARIABLE1)) +
  geom_point() +
  facet_wrap(CATEGORICAL_VARIABLE1 ~ CATEGORICAL_VARIABLE2) +
  labs(x="NICE X AXIS LABEL", y = "NICE Y AXIS LABEL", title = "NICE TITLE") +
    Theme


###################
# PANELS IN GENERAL
###################
# The code for panels or facets as they are called in R can be added to any type of graph.


######################################
# VISUALISING MANY NUMERICAL VARIABLES
######################################
# All variables in the data frame must be numeric.
ggpairs(MYDATA, diag = "blank") +
  Theme
# All variables in the data frame must be numeric; suppress the correlations.
ggpairs(MYDATA, diag = "blank", upper = "blank") +
  Theme


# All variables in the data frame must be numeric. Adding smoother, for example.
ggpairs(MYDATA, diag = "blank",lower = list(continuous = wrap("smooth", method = "loess"))) +
  Theme



# If the data frame includes non-numerical variables, 
# a new data frame with only the numerical variables included can be created.
# In the example below, columns 1,2, 4 and 5 are selected.
# Then the new data frame "newdata" can be used as above.
newdata <- MYDATA[c(1,2,4,5)]
