
# For probability calculations, you don't need packages, or a data file.


############################################
# General structure of probability functions
############################################

# R offers the same form for many different distributions; 4 functions, whose
# purpose is defined by the initial letter of the function:

# "d" for density, which is short-hand for probability density function (continuous rvs)
# or probability function (discrete rvs)

# "p" for the 'distribution function', also known as the cumulative distribution function

# "q" for the quantiles, also known as the inverse cumulative distribution function

# "r" for data randomly generated from the distribution.

########################
# Normal distribution
########################

# To get the value of the probability density function
dnorm(x,mean,sd)
# We usually don't need, want or use this,unless we want to actually plot the pdf

# To obtain the cumulative distribution function, i.e. Pr(X <= x):
pnorm(x,mean,sd)

# For example:
pnorm(1.96,0,1)

# If you omit the mean and sd, the assumed values are mean = 0 and sd = 1, i.e. the
# standard Normal.  For example:

pnorm(1.96)

# This uses a default setting for one of the arguments, which is 'lower.tail=T')

pnorm(1.96,0,1,lower.tail=TRUE)
# This is explicitly saying we want the cdf, i.e. Pr(X <= 1.96)

# The input x can be a vector, in which case the result will be the corresponding vector of
# probabilities.  For example

x <- c(-30:30/10)
cumul1 <- pnorm(x,0,1)
cdf <- cbind(x,cumul1)
cdf

# To plot the cdf simply:
plot(x,cumul1,type="l",las=1,ylab = "Cumulative distribution function, N(0,1)")
grid()

# To obtain Pr(X >= x):
pnorm(x,mean,sd,lower.tail=FALSE)

# For example:
pnorm(1.96,0,1,lower.tail=FALSE)

# To obtain quantiles of the normal distribution, or the inverse cdf:
qnorm(p, mean, sd, lower.tail = TRUE)
# p must be be a probability, and therefore between 0 and 1.
# For example:
qnorm(0.975,0,1,lower.tail=TRUE)

# mean = 0, sd = 1 and lower.tail = TRUE are the defaults:
qnorm(0.975)
