
# For probability calculations, you don't need packages, or a data file.


############################################
# General structure of probability functions
############################################

# R offers the same form for many different distributions; 4 functions, whose
# purpose is defined by the initial letter of the function:

# "d" for density, which is short-hand for probability density function (continuous rvs)
# or probability function (discrete rvs)

# "p" for the 'distribution function', also known as the cumulative distribution function

# "q" for the quantiles, also known as the inverse cumulative distribution function

# "r" for data randomly generated from the distribution.

########################
# Binomial distribution
########################

# To get the individual probabilities, i.e. Pr(X=x)::
dbinom(x,n,theta)

# For example
dbinom(4,10,0.33)

# The input x can be a vector, in which case the result will be the corresponding vector of
# probabilities.  For example

x <- c(0:10)
p1 <- dbinom(x,10,0.33)

# To obtain the cumulative distribution function, i.e. Pr(X <= x):

pbinom(x,n,theta)

# For example:
pbinom(4,10,0.33)

# This uses a default setting for one of the arguments, which is 'lower.tail=T')

pbinom(4,10,0.33,lower.tail=TRUE)
# This is explicitly saying we want the cdf, i.e. Pr(X <= 4), i.e. the probability of 4 
# or values lower than 4.

# The input x can be a vector, in which case the result will be the corresponding vector of
# probabilities.  For example

x <- c(0:10)
cumul1 <- dbinom(x,10,0.33)


# To obtain Pr(X > x):
pbinom(x,n,theta,lower.tail=FALSE)

# It's very important to notice the ">" symbol: "greater than".  NOT "greater than or equal to"

# For example, to get Pr(X > 4):
pbinom(4,10,0.33,lower.tail=FALSE)
# The answer here is Pr(X > 4) = Pr(X >= 5)


# For discrete distributions, the quantile function is not used in SRW.

