# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(summarytools)
library(tidyverse)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

##################################
# ONE SAMPLE INFERENCE FOR A MEAN
##################################

# Start with an appropriate plot (choose one)

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE)) +
  geom_histogram() +
  labs(x="NICE AXIS LABEL!")

ggplot(MYDATA, aes(x=NUMERICAL_VARIABLE)) + 
  geom_dotplot() +
  labs(x="NICE AXIS LABEL!") +
  scale_y_continuous(breaks=NULL)

ggplot(MYDATA, aes(y=NUMERICAL_VARIABLE)) + 
  geom_boxplot() + 
  labs(y="NICE AXIS LABEL!") +
  coord_flip() +
  scale_x_continuous(breaks=NULL)

# Summary statistics

descr(MYDATA, NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd"))

# Confidence interval and hypothesis test for a population mean

t.test(MYDATA$NUMERICAL_VARIABLE, conf.level=0.95)


#####################################################
# INFERENCE FOR A DIFFERENCE OF MEANS: PAIRED SAMPLES
#####################################################

# If the differences are stored in the data file, the code for ONE SAMPLE INFERENCE FOR A MEAN can be used.
# Appropriate graphs are based on the difference scores.

# The statistical inference can be carried out if the paired data are in two separate columns, using the following code.
t.test(MYDATA$NUMERICAL_VARIABLE_Column1, MYDATA$NUMERICAL_VARIABLE_Column2, paired = TRUE)

##########################################################
# INFERENCE FOR A DIFFERENCE OF MEANS: INDEPENDENT SAMPLES
##########################################################

# Start with an appropriate plot (Choose one)

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
  geom_dotplot(binaxis = 'y', dotsize = 0.5) +
  labs(y ="NICE Y-AXIS LABEL", x = "NICE X-AXIS LABEL") +
  coord_flip() 

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
  geom_dotplot(binaxis = 'y', stackdir='center', dotsize = 0.5) +
  labs(y ="NICE Y-AXIS LABEL", y = "", x = "NICE X-AXIS LABEL") +
  coord_flip()

ggplot(MYDATA, aes(x = CATEGORICAL_VARIABLE, y = NUMERICAL_VARIABLE)) + 
  geom_boxplot(width = 0.4) +
  labs(y ="NICE Y-AXIS LABEL", x = "NICE X-AXIS LABEL") +
  coord_flip()


# Use the following code if the numerical variable is stored in one column (vector) and the grouping variable in a second column (factor).

MYDATA %>%
  group_by(CATEGORICAL_VARIABLE) %>%
  descr(NUMERICAL_VARIABLE, stats = c("n.valid", "mean", "sd"))

# Without assuming equal variances
t.test(NUMERICAL_VARIABLE ~ CATEGORICAL_VARIABLE, data = MYDATA, conf.level=0.95)

# Assuming equal variances
t.test(NUMERICAL_VARIABLE ~ CATEGORICAL_VARIABLE, data = MYDATA, var.equal=TRUE, conf.level=0.95)


# Use the following code if the numerical variable for each group is stored in separate columns (vectors).

descr(MYDATA, NUMERICAL_VARIABLE1, stats = c("n.valid", "mean", "sd"))
descr(MYDATA, NUMERICAL_VARIABLE2, stats = c("n.valid", "mean", "sd"))

t.test(NUMERICAL_VARIABLE1, NUMERICAL_VARIABLE_2, data = MYDATA)
