# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(summarytools)
library(tidyverse)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.


####################################
# INFERENCE FOR A SINGLE PROPORTION
####################################

# For a single proportion with a numerator and denominator, both as ordinary numbers:

binom.test(NUMERATOR,DENOMINATOR)

# This gives so-called "exact inferences", which means they are based on
# assuming the binomial distribution. It gives a 95% confidence interval for the
# true proportion.  It also provides a hypothesis test of the null hypothesis
# that the true value of the proportion is a given value, 0.5 by default.

# Sometimes a "large sample" approximation is used:

prop.test(NUMERATOR,DENOMINATOR,correct = FALSE)

# This gives the point estimate and 'large sample' 95% confidence interval for a
# single proportion.  It also provides an hypothesis test of the null hypothesis
# that the true value of the proportion is a given value, 0.5 by default.

# For the same inference when the data are stored in a variable, as zeroes and ones:

x1 <- table(MYDATA$BINARY_VARIABLE)
prop.test(x1,correct = FALSE)

# x1 will be ordered, and the first value in the table will be
# taken as the numerator.  We probably do not want that. 
# This will fix the problem:

x2 <- table(factor(MYDATA$BINARY_VARIABLE,levels=c(1,0)))
prop.test(x2,correct = FALSE)


####################################################################
# INFERENCE FOR A DIFFERENCE OF TWO PROPORTIONS: INDEPENDENT SAMPLES
####################################################################

# For summarised data, use the following.

num <- c(NUMERATOR_1, NUMERATOR_2)  # vector of the two numerators
den <- c(DENOMINATOR_1, DENOMINATOR_2)  # vector of the two denominators

prop.test(num,den,correct=FALSE)

# This gives the 'large sample' 95% confidence interval for the difference of
# the two proportions.  It also provides an hypothesis test of the null hypothesis
# that the two population proportions are equal.

# For data in long form, with a grouping variable and a binary outcome variable:

x3 <- table(MYDATA$GROUP_VARIABLE, MYDATA$BINARY_VARIABLE)
prop.test(x3,correct=FALSE)

# The prop.test command does not give the point estimate of the
# difference of the proportions; it needs to be calculated.
# For example:

result1 <- prop.test(num,den,correct=FALSE)
pdiff <- as.numeric(result1$estimate[1] - result1$estimate[2])
print(pdiff)

# Or:

x3 <- table(MYDATA$GROUP_VARIABLE, MYDATA$BINARY_VARIABLE)
result2 <- prop.test(x3,correct=FALSE)
pdiff <- as.numeric(result2$estimate[1] - result2$estimate[2])
print(pdiff)

