# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(summarytools)
library(dplyr)
library(gmodels)


# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.


##########################################################
# INFERENCE FOR TWO WAY TABLES
##########################################################

# Start with an appropriate plot (Choose one)

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE1, y = ..count.., fill=CATEGORICAL_VARIABLE2)) + 
  geom_bar(position="dodge") +
  labs(x="NICE CATEGORICAL_VARIABLE1 LABEL", y = "Frequency", title = "NICE TITLE") +
  coord_flip()

ggplot(MYDATA, aes(x=CATEGORICAL_VARIABLE1, y = 100*(..count..)/sum(..count..), fill=CATEGORICAL_VARIABLE2)) + 
  geom_bar(position="dodge") +
  labs(x="NICE CATEGORICAL_VARIABLE1 LABEL", y = "Percent", title = "NICE TITLE (%)") +
  coord_flip()

TwoWaytable <- MYDATA %>%
  count(CATEGORICAL_VARIABLE2, CATEGORICAL_VARIABLE1) %>%
  group_by(CATEGORICAL_VARIABLE2) %>%
  mutate(proportion = n / sum(n)) %>%
  ungroup()
ggplot(TwoWaytable, aes(x = 100*proportion, y = CATEGORICAL_VARIABLE1)) + 
  geom_point(size = 3) +
  geom_segment(aes(x=0, 
                   xend=100*proportion, 
                   y=CATEGORICAL_VARIABLE1, 
                   yend=CATEGORICAL_VARIABLE1)) +
  facet_grid(rows=vars(CATEGORICAL_VARIABLE2)) +
  labs(x = "Percentage within CATEGORICAL_VARIABLE2", y = "", title = "CATEGORICAL_VARIABLE1 (%) within each level of CATEGORICAL_VARIABLE2") +

# Produce a cross tabulation
ctable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2)

# Produce a cross tabulation with Chi-squared test of association
ctable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2, chisq=TRUE)
#or
CrossTable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2, chisq=TRUE) 

# Produce a cross tabulation with Chi-squared test of association, with expected counts and contribution to chi-squared statistic
CrossTable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2, chisq=TRUE, expected= TRUE, prop.r=FALSE, prop.c=FALSE, prop.t=FALSE) 

# Produce a cross tabulation with Chi-squared test of association and Fisher's exact test (2 by 2 tables)
CrossTable(MYDATA$CATEGORICAL_VARIABLE1, MYDATA$CATEGORICAL_VARIABLE2, chisq=TRUE, fisher = TRUE)  