# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(pwr)

# For determining sampling sizes using testing theory you don't read in a data file.

#####################################
# SAMPLE SIZE FOR COMPARING TWO MEANS
#####################################

pwr.t.test(n , d , sig.level , power, type = "two.sample")
            
# n = sample size IN EACH GROUP
# d = Effect size expressed as Cohen's d = (minimum interesting difference of means)/assumed within group sd
# sig.level = Pr(type 1 error) = alpha, default = 0.05
# power = statistical power, must be set by the user

# When used, exactly one of n, d, power, and sig.level must be NULL; usually, this is the sample size

# For example:

pwr.t.test(n = , d = 2/7, sig.level = 0.05, power = 0.80, type = "two.sample")

# You don't need to include 'n = ' here, but it reminds you what you're doing:

pwr.t.test(d = 2/7, sig.level = 0.05, power = 0.80, type = "two.sample")

###########################################
# SAMPLE SIZE FOR COMPARING TWO PROPORTIONS
###########################################

# This uses an arcsine approximation, so it is a two step-process

# First the effect size is calculated on a transformed scale; you need to input the two
# assumed proportions under the alternative hypothesis

h <- ES.h(p1,p2)

# Then use this effect size in the following function

pwr.2p.test(h , n , sig.level, power, alternative = "two.sided")

# For example:

h <- ES.h(0.2, 0.3)
pwr.2p.test(h, n = , sig.level = 0.05, power = 0.8, alternative = "two.sided")

# Defaults can be used:
pwr.2p.test(h, n = , power = 0.8)

# You don't need to include 'n = ' here, but it reminds you what you're doing:

pwr.2p.test(h, power = 0.8)
