# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(emmeans)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

############################################
# ANALYSIS OF VARIANCE OF A FACTORIAL DESIGN
############################################

# THis analysis assumes two factors in the design.

# Construct an appropriate 'interaction' plot to show the means by the combinations of the factors.

# For example:

ggplot(MYDATA, (aes(y=RESPONSE_VARIABLE, x=FACTOR1, colour = FACTOR2, group = FACTOR2))) +
  stat_summary(fun.y = mean,geom = "line") +
  labs(y = "NICE.Y.LABEL", x = "NICE.FACTOR1.LABEL", colour="FACTOR2")

# Obtain the ANOVA:

MY.MODEL <- lm(RESPONSE_VARIABLE ~ FACTOR1+FACTOR2+FACTOR1:FACTOR2, data=MYDATA)
anova(MY.MODEL)

# Check the assumptions:

plot(MY.MODEL)

# Look at all pairwise comparisons 

pairs(emmeans(MY.MODEL, ~ FACTOR1 * Process), adjust = "none")

#  Consider the pairwise comparisons for one factor, by each level of the other factor.
#  This is particularly useful when one factor, say, FACTOR1, has only two levels.

pairs(emmeans(MY.MODEL, "FACTOR1", by = "FACTOR2"), adjust = "none")
confint(pairs(emmeans(MY.MODEL, "FACTOR1", by = "FACTOR2"), adjust = "none"))

# If there is little evidence of a marked interaction, then it can be useful to fit
# a 'main effects' model and interpret that data using that model:

MY.MAIN.EFFECTS.MODEL <- lm(RESPONSE_VARIABLE ~ FACTOR1+FACTOR2, data=MYDATA)
anova(MY.MAIN.EFFECTS.MODEL)