# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(car)
library(summarytools)
library(tidyverse)
library(emmeans)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

##############################
# ONE WAY ANALYSIS OF VARIANCE
##############################

# Graph the data first: a dotplot by treatment for a small data set, or 
# boxplot by treatment

# To obtain the analysis, use the 'lm' function ("linear model"):

MY.MODEL1 <- lm(NUMERICAL_RESPONSE ~ CATEGORICAL_EXPLANATORY, data=MYDATA)
anova(MY.MODEL1)
MYDATA %>%
  group_by(CATEGORICAL_EXPLANATORY) %>%
  descr(NUMERICAL_RESPONSE, stats = c("n.valid", "mean", "sd"))

# To look at the diagnostics for the suitability of the model:
plot(MY.MODEL1)

# To test the equal variances assumption:
leveneTest(NUMERICAL_RESPONSE ~ CATEGORICAL_EXPLANATORY, data=MYDATA)

# To examine pairwise differences:
RESPONSE_emm <- emmeans(MY.MODEL1, "CATEGORICAL_EXPLANATORY")

# estimated means and confidence intervals
summary(RESPONSE_emm)

# pairwise tests, Fisher LSD
summary(pairs(RESPONSE_emm, adjust = "none"), infer = TRUE)

# pairwise tests, Tukey HSD (default)
summary(pairs(RESPONSE_emm, adjust = "tukey"), infer = TRUE)

# compact letter display, based on Tukey tests
cld(RESPONSE_emm, adjust = "tukey")

# plot Tukey confidence intervals for pairwise differences
plot(pairs(RESPONSE_emm, adjust = "tukey")) +
  labs(title = "Tukey's 95% confidence intervals",
       x = "Mean difference",
       y = NULL)

