# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(car)
library(summarytools)
library(tidyverse)
library(emmeans)

# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

####################################################
# TWO WAY ANALYSIS OF VARIANCE FOR RANDOMISED BLOCKS
####################################################

# To obtain the analysis, use the 'lm' function ("linear model"):

MY.MODEL2 <- lm(NUMERICAL_RESPONSE ~ BLOCK + TREATMENT, data=MYDATA)
anova(MY.MODEL2)
MYDATA %>%
  group_by(TREATMENT) %>%
  descr(NUMERICAL_RESPONSE, stats = c("n.valid", "mean", "sd"))

# To look at the diagnostics for the suitability of the model:
plot(MY.MODEL2)

# To examine pairwise differences:
RESPONSE_emm2 <- emmeans(MY.MODEL2, "TREATMENT")  # We usually care about TREATMENT but not BLOCK

# estimated means and confidence intervals
summary(RESPONSE_emm2)

# pairwise tests, Fisher LSD
summary(pairs(RESPONSE_emm2, adjust = "none"), infer = TRUE)

# pairwise tests, Tukey HSD (default)
summary(pairs(RESPONSE_emm2, adjust = "tukey"), infer = TRUE)

# compact letter display, based on Tukey tests
cld(RESPONSE_emm2, adjust = "tukey")

# plot Tukey confidence intervals for pairwise differences
plot(pairs(RESPONSE_emm2, adjust = "tukey")) +
  labs(title = "Tukey's 95% confidence intervals",
       x = "Mean difference",
       y = NULL)

