# Set your working directory.

# Load the packages you need.
# If there's a package below that you don't have, you will need to install it first:
# Tools > Install Packages ... (then request the missing packages).

library(ggplot2)
library(tidyverse)
library(emmeans)


# Read in the data.
# In this script, the file is called MYDATA.RData.  Replace this with the name of the file you wish to use.

load("MYDATA.Rdata")

# In all of the code below, you will need to replace MYDATA with the name of your data frame.
# You will need to use the appropriate variable names.

##############################
# LOGISTIC REGRESSION ANALYSES
##############################

#  Fit logistic regression with one categorical explanatory variable

summary(MY.MODEL1 <- glm(BINARY_RESPONSE ~ CATEGORICAL_EXPLANATORY, family="binomial", data=MYDATA))

coefficients(MY.MODEL1)

confint(MY.MODEL1)

# Obtain inferences on the odds ratio scale.

or.inference <- exp(confint.default(MY.MODEL1))
print(or.inference)

# Obtain pairwise comparisons on the odds ratio scale.

emm.1 <- emmeans(MY.MODEL1, "CATEGORICAL_EXPLANATORY", type = "response")
pair.comparisons <- pairs(emm.1, reverse = TRUE, infer=TRUE, adjust = "none")
print(pair.comparisons)


#  Fit logistic regression with one numerical explanatory variable

summary(MY.MODEL2 <- glm(BINARY_RESPONSE ~ NUMERICAL_EXPLANATORY, family="binomial", data=MYDATA))

#  Get the estimated coefficients

coefficients(MY.MODEL2)

# Obtain the estimate and confidence interval on the odds ratio scale

exp(coefficients(MY.MODEL2))
exp(confint.default(MY.MODEL2))


# Multiple logistic regression

MY.MODEL3 <- glm(BINARY_RESPONSE ~ EXPLANATORY1 + EXPLANATORY2 + ..., family="binomial", data=MYDATA)
summary(MY.MODEL3)
coefficients(MY.MODEL3)
confint(MY.MODEL3)

# The confidence intervals obtained so far are on the log odds scale.
# To obtain them on the odds ratio scale:

exp(coefficients(MY.MODEL3))
exp(confint.default(MY.MODEL3))

# The standard output for a categorical explanatory variable compares
# levels 2, 3, ..., k with level 1, according to the ordered levels of
# the variable.

# Sometimes we want all the pairwise comparisons for a 
# categorical explanatory variable; usually we want this on the
# odds ratio scale.

emm.3 <- emmeans(MY.MODEL3, "CATEGORICAL_EXPLANATORY", type = "response")
pair.comparisons <- pairs(emm.3, reverse=TRUE, infer=TRUE, adjust= "none")


